==> digikam_4.12.0.orig.tar.bz2: digikam-4.12.0/extra/kipi-plugins/videoslideshow/plugin/kipiplugin_videoslideshow.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
UntranslatedGenericName=VideoSlideShow
Name=VideoSlideShow
Name[bs]=Video prezentacija
Name[ca]=Passi de diapositives
Name[ca@valencia]=Passe de diapositives
Name[cs]=VideoSlideShow
Name[da]=Video-diasshow
Name[de]=Video-Diaschau
Name[el]=VideoSlideShow
Name[en_GB]=VideoSlideShow
Name[es]=Presentación de vídeo
Name[et]=Videoslaidiseanss
Name[fr]=Diaporama vidéo
Name[ga]=VideoSlideShow
Name[gl]=VideoSlideShow
Name[hu]=Videóbemutató
Name[is]=Vídeóskyggnusýning
Name[it]=Presentazione video
Name[nb]=VideoSlideShow
Name[nl]=Diavoorstelling met video
Name[pl]=Pokaz slajdów filmów
Name[pt]=Apresentação de Vídeo
Name[pt_BR]=Apresentação de vídeo
Name[ru]=Видео слайд-шоу
Name[sk]=VideoSlideShow
Name[sl]=VideoSlideShow
Name[sv]=Videobildspel
Name[tr]=Video Slayt Gösterisi
Name[uk]=Відеопоказ слайдів
Name[x-test]=xxVideoSlideShowxx
Name[zh_TW]=VideoSlideShow
Comment=A tool to export images as Video Slide Show
Comment[bs]=Alat za izvoz slika kao video prezentacija
Comment[ca]=Una eina per exportar imatges com un passi de diapositives
Comment[ca@valencia]=Una eina per exportar imatges com un passe de diapositives
Comment[cs]=Nástroj pro export obrázků jako video prezentace
Comment[da]=Et værktøj til at eksportere billeder som et video-diasshow
Comment[de]=Ein Werkzeug, um Bilder als Video-Diaschau zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων ως παρουσίαση διαφανειών βίντεο
Comment[en_GB]=A tool to export images as Video Slide Show
Comment[es]=Herramienta para exportar imágenes como una presentación de vídeo
Comment[et]=Tööriist piltide eksportimiseks videoslaidiseansina
Comment[fr]=Un outil d'exportation d'images en diaporama vidéo
Comment[gl]=Ferramenta para exportar imaxes como un vídeo-presentación.
Comment[hu]=Egy eszköz képek exportálásához videóbemutatóba
Comment[is]=Verkfæri til að flytja myndir út sem vídeóskyggnusýningu
Comment[it]=Uno strumento per esportare immagini come presentazione video
Comment[nb]=Et verktøy for å eksportere bilder som video lysbildeframvisning
Comment[nl]=Een hulpmiddel voor het exporteren van afbeeldingen als diavoorstelling met video
Comment[pl]=Narzędzie do eksporty obrazów jako pokaz slajdów filmów
Comment[pt]=Uma ferramenta para exportar imagens como uma apresentação de vídeo
Comment[pt_BR]=Ferramenta para exportar imagens como uma apresentação em vídeo
Comment[ru]=Инструмент для экспорта изображений в слайд-шоу в видеофайле
Comment[sk]=Nástroj na export obrázkov ako video slide show
Comment[sl]=Orodje za izvoz slik v video predstavitev
Comment[sv]=Ett verktyg för att exportera bilder som ett videobildspel
Comment[tr]=Resimleri Video Slayt Gösterisi olarak aktarmak için bir araç
Comment[uk]=Інструмент для експортування зображень у форматі відеопоказу слайдів
Comment[x-test]=xxA tool to export images as Video Slide Showxx
Comment[zh_TW]=匯出影像到 Video Slide Show 的工具
Type=Service
Icon=media-record
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_videoslideshow
author=A Janardhan Reddy, annapareddyjanardhanreddy at gmail dot com
X-KIPI-ReqFeatures=
X-KIPI-PluginCategories=Tools
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}

==> digikam-4.14.0.tar.bz2: digikam-4.14.0/extra/kipi-plugins/videoslideshow/plugin/kipiplugin_videoslideshow.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
UntranslatedGenericName=VideoSlideShow
Name=VideoSlideShow
Name[bs]=Video prezentacija
Name[ca]=Passi de diapositives
Name[ca@valencia]=Passe de diapositives
Name[cs]=VideoSlideShow
Name[da]=Video-diasshow
Name[de]=Video-Diaschau
Name[el]=VideoSlideShow
Name[en_GB]=VideoSlideShow
Name[es]=Presentación de vídeo
Name[et]=Videoslaidiseanss
Name[fr]=Diaporama vidéo
Name[ga]=VideoSlideShow
Name[gl]=VideoSlideShow
Name[hu]=Videóbemutató
Name[is]=Vídeóskyggnusýning
Name[it]=Presentazione video
Name[nb]=VideoSlideShow
Name[nl]=Diavoorstelling met video
Name[pl]=Pokaz slajdów filmów
Name[pt]=Apresentação de Vídeo
Name[pt_BR]=Apresentação de vídeo
Name[ru]=Видео слайд-шоу
Name[sk]=VideoSlideShow
Name[sl]=VideoSlideShow
Name[sv]=Videobildspel
Name[tr]=Video Slayt Gösterisi
Name[uk]=Відеопоказ слайдів
Name[x-test]=xxVideoSlideShowxx
Name[zh_TW]=VideoSlideShow
Comment=A tool to export images as Video Slide Show
Comment[bs]=Alat za izvoz slika kao video prezentacija
Comment[ca]=Una eina per exportar imatges com un passi de diapositives
Comment[ca@valencia]=Una eina per exportar imatges com un passe de diapositives
Comment[cs]=Nástroj pro export obrázků jako video prezentace
Comment[da]=Et værktøj til at eksportere billeder som et video-diasshow
Comment[de]=Ein Werkzeug, um Bilder als Video-Diaschau zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων ως παρουσίαση διαφανειών βίντεο
Comment[en_GB]=A tool to export images as Video Slide Show
Comment[es]=Herramienta para exportar imágenes como una presentación de vídeo
Comment[et]=Tööriist piltide eksportimiseks videoslaidiseansina
Comment[fr]=Un outil d'export d'images en diaporama vidéo
Comment[gl]=Ferramenta para exportar imaxes como un vídeo-presentación.
Comment[hu]=Egy eszköz képek exportálásához videóbemutatóba
Comment[is]=Verkfæri til að flytja myndir út sem vídeóskyggnusýningu
Comment[it]=Uno strumento per esportare immagini come presentazione video
Comment[nb]=Et verktøy for å eksportere bilder som video lysbildeframvisning
Comment[nl]=Een hulpmiddel voor het exporteren van afbeeldingen als diavoorstelling met video
Comment[pl]=Narzędzie do eksporty obrazów jako pokaz slajdów filmów
Comment[pt]=Uma ferramenta para exportar imagens como uma apresentação de vídeo
Comment[pt_BR]=Ferramenta para exportar imagens como uma apresentação em vídeo
Comment[ru]=Инструмент для экспорта изображений в слайд-шоу в видеофайле
Comment[sk]=Nástroj na export obrázkov ako video slide show
Comment[sl]=Orodje za izvoz slik v video predstavitev
Comment[sv]=Ett verktyg för att exportera bilder som ett videobildspel
Comment[tr]=Resimleri Video Slayt Gösterisi olarak aktarmak için bir araç
Comment[uk]=Інструмент для експортування зображень у форматі відеопоказу слайдів
Comment[x-test]=xxA tool to export images as Video Slide Showxx
Comment[zh_TW]=匯出影像到 Video Slide Show 的工具
Type=Service
Icon=media-record
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_videoslideshow
author=A Janardhan Reddy, annapareddyjanardhanreddy at gmail dot com
X-KIPI-ReqFeatures=
X-KIPI-PluginCategories=Tools
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
